@@ -3,6 +3,7 @@ import logging
 import requests
 import time
 import urllib.parse
+import uuid
 import webbrowser
 
 import io
@@ -24,7 +25,7 @@ from .utils.selenium_core import SeleniumDriverCore
 
 class SmartDriver(SeleniumDriverCore):
     def __init__(self, driver, api_key, initialization_dict={}):
-        self.version = 'appium-0.1.24'
+        self.version = 'appium-0.1.25'
         self.root_elem = None
         caps = driver.desired_capabilities
         self.automation_name = caps.get('automationName', '')
@@ -61,19 +62,24 @@ class SmartDriver(SeleniumDriverCore):
                 element = real_elem
                 return element, self.last_test_case_screenshot_uuid, msg
             else:
-                label_url = self.url + '/testcase/label?test_case_name=' + urllib.parse.quote(self.test_case_uuid)
+                event_id = str(uuid.uuid4())
+                label_url = f'{self.url}/testcase/label?test_case_name={urllib.parse.quote(self.test_case_uuid)}&event_id={event_id}&api_key={self.api_key}'
                 log.info('Waiting for bounding box of element {} to be drawn in the UI: \n\t{}'.format(element_name,
                                                                                                        label_url))
                 webbrowser.open(label_url)
                 while True:
-                    element_box, needs_reload = self._test_case_get_box(element_name)
+                    element_box, needs_reload = self._test_case_get_box(element_name, event_id=event_id)
                     if element_box is not None:
                         print('Element was labeled, moving on')
                         real_elem = self._match_bounding_box_to_web_element(element_box, multiplier=self.multiplier)
                         element = ai_elem(real_elem.parent, real_elem._id, element_box, self.driver,
                                           self.multiplier, smart_driver=self, base_elem=real_elem)
                         return element, self.last_test_case_screenshot_uuid, msg
-                    time.sleep(2)
+
+                    if needs_reload:
+                        print('hot release')
+                        self._test_case_upload_screenshot(element_name)
+                    time.sleep(1)
         else:
             element = None
             run_key = None
@@ -188,7 +194,7 @@ class SmartDriver(SeleniumDriverCore):
                     if not contains_non_interactable:
                         return element
 
-        if len(composite) == 0:
+        if iou_composite[0][0] < 0.25:
             raise NoElementFoundException('Could not find any web element under the center of the bounding box')
         else:
             for score, element in composite:
